import React, { useState, useEffect } from "react";
import Post from "./components/Post";
import ActionButtons from "./components/ActionButtons";
import CommentForm from "./components/CommentForm";
import CommentsModal from "./components/CommentsModal";

const App = () => {
  // State declarations
  const [likes, setLikes] = useState(0);
  const [comments, setComments] = useState([]);
  const [newComment, setNewComment] = useState("");
  const [showComments, setShowComments] = useState(false);

  // Persist likes and comments in localStorage
  useEffect(() => {
    localStorage.setItem("likes", likes);
  }, [likes]);

  useEffect(() => {
    localStorage.setItem("comments", JSON.stringify(comments));
  }, [comments]);

  // Handlers
  const handleLike = () => setLikes((prev) => prev + 1);

  const handleSubmit = (e) => {
    e.preventDefault();
    if (newComment.trim()) {
      setComments((prev) => [...prev, { text: newComment }]);
      setNewComment("");
    }
  };

  return (
    <div className="container mx-auto p-4 bg-white shadow rounded-lg max-w-2xl">
      <Post />
      <div className="flex justify-between mb-4 pb-2 border-b">
        <span>{likes} likes</span>
        <span>{comments.length} comments</span>
      </div>
      <ActionButtons handleLike={handleLike} setShowComments={setShowComments} />
      <CommentForm
        newComment={newComment}
        setNewComment={setNewComment}
        handleSubmit={handleSubmit}
      />
      <CommentsModal
        showComments={showComments}
        setShowComments={setShowComments}
        comments={comments}
      />
    </div>
  );
};

export default App;
